@@ -78,7 +78,7 @@ def every_3_seconds():
     if(only_one_time):
         only_one_time = False
         folders.loadExchangeFolder()
-    
+
 
     try:
         coat3D = bpy.context.scene.coat3D
@@ -96,7 +96,7 @@ def every_3_seconds():
 
     except:
         pass
-    
+
     return 3.0
 
 @persistent
@@ -207,10 +207,10 @@ def updatemesh(objekti, proxy, texturelist):
                     if(udim_textures):
                         udim = proxy.data.uv_layers[index].name
                         udim_index = int(udim[2:]) - 1
-    
+
                     objekti.data.uv_layers[0].data[indi].uv[0] = proxy.data.uv_layers[index].data[indi].uv[0]
                     objekti.data.uv_layers[0].data[indi].uv[1] = proxy.data.uv_layers[index].data[indi].uv[1]
-            
+
         index = index + 1
 
     # Mesh Copy
@@ -225,9 +225,9 @@ class SCENE_OT_getback(bpy.types.Operator):
     bl_label = "Export your custom property"
     bl_description = "Export your custom property"
     bl_options = {'UNDO'}
-    
+
     def invoke(self, context, event):
-        
+
         global global_exchange_folder
         path_ex = ''
 
@@ -236,23 +236,23 @@ class SCENE_OT_getback(bpy.types.Operator):
 
         BlenderFolder = Blender_folder
         ExportFolder = Export_folder
-        
+
         Blender_folder += ('%sexport.txt' % (os.sep))
         Export_folder += ('%sexport.txt' % (os.sep))
-        
+
         if (bpy.app.background == False):
             if os.path.isfile(Export_folder):
-                
+
                 print('BLENDER -> 3DC -> BLENDER WORKFLLOW')
-                DeleteExtra3DC() 
+                DeleteExtra3DC()
                 workflow1(ExportFolder)
                 removeFile(Export_folder)
-                removeFile(Blender_folder)    
-            
+                removeFile(Blender_folder)
+
             elif os.path.isfile(Blender_folder):
 
                 print('3DC -> BLENDER WORKFLLOW')
-                DeleteExtra3DC() 
+                DeleteExtra3DC()
                 workflow2(BlenderFolder)
                 removeFile(Blender_folder)
 
@@ -263,23 +263,23 @@ class SCENE_OT_savenew(bpy.types.Operator):
     bl_label = "Export your custom property"
     bl_description = "Export your custom property"
     bl_options = {'UNDO'}
-    
+
     def invoke(self, context, event):
-        
+
         coat3D = bpy.context.scene.coat3D
         platform = os.sys.platform
-    
+
         if(platform == 'win32' or platform == 'darwin'):
             exchangeFile = os.path.expanduser("~") + os.sep + 'Documents' + os.sep + '3DC2Blender' + os.sep + 'Exchange_folder.txt'
         else:
             exchangeFile = os.path.expanduser("~") + os.sep + '3DC2Blender' + os.sep + 'Exchange_folder.txt'
         if(os.path.isfile(exchangeFile)):
             folderPath = ''
-        
+
         if(os.path.isfile(exchangeFile)):
             file = open(exchangeFile, "w")
             file.write("%s"%(coat3D.exchangeFolder))
-            file.close()        
+            file.close()
 
         return {'FINISHED'}
 
@@ -331,7 +331,7 @@ class SCENE_OT_opencoat(bpy.types.Operator):
 def scaleParents():
     save = []
     names =[]
-    
+
     for objekti in bpy.context.selected_objects:
         temp = objekti
         while (temp.parent is not None and temp.parent.name not in names):
@@ -527,7 +527,7 @@ class SCENE_OT_export(bpy.types.Operator):
 
     def invoke(self, context, event):
         bpy.ops.export_applink.pilgway_3d_coat()
-      
+
         return {'FINISHED'}
 
     def execute(self, context):
@@ -548,7 +548,7 @@ class SCENE_OT_export(bpy.types.Operator):
 
         export_ok = False
         coat3D = bpy.context.scene.coat3D
-      
+
         if (bpy.context.selected_objects == []):
             return {'FINISHED'}
         else:
@@ -574,11 +574,11 @@ class SCENE_OT_export(bpy.types.Operator):
 
         if (os.path.isfile(Blender_folder2)):
             os.remove(Blender_folder2)
-    
+
         if (not os.path.isdir(coat3D.exchangeFolder)):
             coat3D.exchange_found = False
             return {'FINISHED'}
-       
+
         folder_objects = folders.set_working_folders()
         folder_size(folder_objects)
 
@@ -735,7 +735,7 @@ class SCENE_OT_export(bpy.types.Operator):
                                     bpy.data.images.remove(image)
 
                             index_bake_tex += 1
-        
+
         #BAKING ENDS
 
         #bpy.ops.object.origin_set(type='ORIGIN_GEOMETRY')
@@ -789,7 +789,7 @@ class SCENE_OT_export(bpy.types.Operator):
                                     if(node.name.startswith('3DC_') == True):
                                         material.material.node_tree.nodes.remove(node)
 
-        
+
                 for ind, mat_list in enumerate(mod_mat_list):
                     if(mat_list == '__' + objekti.name):
                         for ind, mat in enumerate(mod_mat_list[mat_list]):
@@ -822,7 +822,7 @@ def DeleteExtra3DC():
                     bpy.data.images.remove(del_img)
 
             bpy.data.materials.remove(material)
-    
+
     image_del_list = []
     for image in bpy.data.images:
         if (image.name.startswith('3DC')):
@@ -901,7 +901,7 @@ def new_ref_function(new_applink_address, nimi):
 
 
 def blender_3DC_blender(texturelist, file_applink_address):
-    
+
     coat3D = bpy.context.scene.coat3D
 
     old_materials = bpy.data.materials.keys()
@@ -915,7 +915,7 @@ def blender_3DC_blender(texturelist, file_applink_address):
     for objekti in bpy.data.objects:
         if objekti.type == 'MESH' and objekti.coat3D.applink_address == file_applink_address:
             obj_coat = objekti.coat3D
-            
+
             object_list.append(objekti.name)
             if(os.path.isfile(obj_coat.applink_address)):
                 if (obj_coat.objecttime != str(os.path.getmtime(obj_coat.applink_address))):
@@ -1050,7 +1050,7 @@ def blender_3DC_blender(texturelist, file_applink_address):
 
                         #delete_materials_from_end(keep_materials_count, obj_proxy)
 
-               
+
                         updatemesh(objekti,obj_proxy, texturelist)
                         bpy.context.view_layer.objects.active = objekti
 
@@ -1178,7 +1178,7 @@ def blender_3DC(texturelist, new_applink_address):
 
     old_materials = bpy.data.materials.keys()
     old_objects = bpy.data.objects.keys()
-  
+
     bpy.ops.import_scene.fbx(filepath=new_applink_address, global_scale = 1, axis_forward='-Z', axis_up='Y')
 
     new_materials = bpy.data.materials.keys()
@@ -1253,7 +1253,7 @@ def blender_3DC(texturelist, new_applink_address):
         os.remove(Blender_export)
     if (os.path.isfile(Blender_folder2)):
         os.remove(Blender_folder2)
-        
+
     for material in bpy.data.materials:
         if material.use_nodes == True:
             for node in material.node_tree.nodes:
@@ -1271,9 +1271,9 @@ def workflow1(ExportFolder):
         for image in bpy.data.images:
             if(image.filepath == texturepath[3] and image.users == 0):
                 bpy.data.images.remove(image)
-    
+
     path3b_now = coat3D.exchangeFolder
-    
+
     path3b_now += ('last_saved_3b_file.txt')
     new_applink_address = 'False'
     new_object = False
@@ -1297,7 +1297,7 @@ def workflow1(ExportFolder):
                     new_ref_object = True
                     nimi = scene_objects.name
 
-    
+
 
 
     exportfile = coat3D.exchangeFolder
@@ -1327,9 +1327,9 @@ def workflow2(BlenderFolder):
     kokeilu = coat3D.exchangeFolder
 
     Blender_export = os.path.join(kokeilu, 'Blender')
-    
+
     path3b_now = coat3D.exchangeFolder
-    
+
     path3b_now += ('last_saved_3b_file.txt')
     Blender_export += ('%sexport.txt'%(os.sep))
     new_applink_address = 'False'
@@ -1717,7 +1717,7 @@ class SceneCoat3D(PropertyGroup):
     )
     foundExchangeFolder: BoolProperty(
         name="found Exchange Folder",
-        description="found Excahnge folder",
+        description="found Exchange folder",
         default=False
     )
     delete_images: BoolProperty(
@@ -1821,7 +1821,7 @@ class SceneCoat3D(PropertyGroup):
     )
     bake_resolution: EnumProperty(
         name="Bake Resolution",
-        description="Bake resolution.",
+        description="Bake resolution",
         items=(("res_64", "64 x 64", ""),
                ("res_128", "128 x 128", ""),
                ("res_256", "256 x 256", ""),
@@ -1835,7 +1835,7 @@ class SceneCoat3D(PropertyGroup):
     )
     folder_size: EnumProperty(
         name="Applink folder size",
-        description="Applink folder size.",
+        description="Applink folder size",
         items=(("10", "10", ""),
                ("100", "100", ""),
                ("500", "500", ""),
@@ -2007,7 +2007,7 @@ def register():
         default=True
     )
 
-    
+
 
 
     from bpy.utils import register_class
@@ -2017,7 +2017,7 @@ def register():
     bpy.types.Object.coat3D = PointerProperty(type=ObjectCoat3D)
     bpy.types.Scene.coat3D = PointerProperty(type=SceneCoat3D)
     bpy.types.Mesh.coat3D = PointerProperty(type=MeshCoat3D)
-    bpy.types.Material.coat3D = PointerProperty(type=MaterialCoat3D)  
+    bpy.types.Material.coat3D = PointerProperty(type=MaterialCoat3D)
     bpy.app.handlers.load_post.append(load_handler)
 
     kc = bpy.context.window_manager.keyconfigs.addon
