@@ -489,7 +489,7 @@ if mat:
             return "WARNING", "Select a material"
 
     def get_material(self, name, link=False):
-        with bpy.data.libraries.load(self.current_library.path, link, False) as (data_from, data_to):
+        with bpy.data.libraries.load(self.current_library.path, link=link, relative=False) as (data_from, data_to):
             data_to.materials = [name]
         if link:
             print(name + " linked.")
@@ -523,7 +523,7 @@ if mat:
             return "INFO", "Please select an object"
 
         if dummy == context.object and not preview:
-            if (len(objects)==1 and dummy.select):
+            if (len(objects)==1 and dummy.select_get()):
                 return "ERROR", "Apply is disabled for the Material Preview Object"
             try:
                 last = context.scene.objects[self.last_selected]
@@ -601,7 +601,7 @@ if mat:
         #if material:
         #maybe some test cases doesn't return a material, gotta take care of that
         #i cannot think of any case like that right now
-        #maybe import linked when the database isnt sync
+        #maybe import linked when the database isn't sync
         if context.mode == "EDIT_MESH":
             obj = context.object
             dd(material)
@@ -1072,7 +1072,7 @@ def list_materials():
   return sorted(list)
 
 def get_material(name, link=False):
-  with bpy.data.libraries.load("{0}", link, False) as (data_from, data_to):
+  with bpy.data.libraries.load("{0}", link=link, relative=False) as (data_from, data_to):
     data_to.materials = [name]
   if link:
     print(name + " linked.")
